/******************************** <lalVerbatim file="LALSampleTestCV">
Author: Creighton, T. D.
$Id: LALSampleTest.c,v 1.1 2000/06/29 21:05:38 jolien Exp $
********************************* </lalVerbatim> */

/********************************************************** <lalLaTeX>
\subsection{Program \texttt{LALSampleTest.c}}
\label{ss:LALSampleTest.c}

Example program for LAL.

\subsubsection*{Usage}
\begin{verbatim}
LALSampleTest [numer denom [debuglevel]]
\end{verbatim}

\subsubsection*{Description}

This program demonstrates LAL coding and documentation standards for
test programs.  It reads two numbers \verb@numer@ and \verb@denom@
from the command line, computes their quotient using the function
\verb@REAL8Divide()@, and prints the result to \verb@stdout@.  It is
run with \verb@debuglevel@ = 0, unless set by the optional third
argument.

\subsubsection*{Exit codes}
\input{LALSampleTestCE}

\subsubsection*{Uses}
\begin{verbatim}
debuglevel
LALPrintError()
REAL8Divide()
\end{verbatim}

\subsubsection*{Notes}

\vfill{\footnotesize\input{LALSampleTestCV}}
******************************************************* </lalLaTeX> */

#include <stdlib.h>
#include "LALStdlib.h"
#include "LALSample.h"

NRCSID( LALSAMPLETESTC, "$Id: LALSampleTest.c,v 1.1 2000/06/29 21:05:38 jolien Exp $" );

/***************************** <lalErrTable file="LALSampleTestCE"> */
#define LALSAMPLETESTC_ENOM 0
#define LALSAMPLETESTC_EARG 1
#define LALSAMPLETESTC_ESUB 2
#define LALSAMPLETESTC_MSGENOM "Nominal exit"
#define LALSAMPLETESTC_MSGEARG "Error parsing command-line arguments"
#define LALSAMPLETESTC_MSGESUB "Subroutine returned error"
/***************************** </lalErrTable> */

/* Declare and set the default debuglevel */
int debuglevel = 0;

/* A local macro for printing error messages */
#define EXIT( code, program, message )                                \
  do {                                                                \
    if (( debuglevel & LALERROR ) && (code))                          \
      LALPrintError( "Error[0] %d: program %s, file %s, line %d, %s\n"\
                     "        %s\n", (code), (program), __FILE__,     \
                     __LINE__, LALSAMPLETESTC, (message) );           \
    else if ( debuglevel & LALINFO )                                  \
      LALPrintError( "Info[0]: program %s, file %s, line %d, %s\n"    \
                     "        %s\n", (program), __FILE__, __LINE__,   \
                     LALSAMPLETESTC, (message) );                     \
    return (code);                                                    \
  } while (0)

/* The main function */
int
main( int argc, char **argv )
{
  static Status stat;
  REAL8 ratio;

  /* Parse input line. */
  if ( argc == 1 )
    EXIT( LALSAMPLETESTC_ENOM, argv[0], LALSAMPLETESTC_MSGENOM );
  else if ( argc == 4 )
    debuglevel = atoi( argv[3] );
  else if ( argc != 3 )
    {
      LALPrintError( "Usage: %s [numer denom [ debuglevel ]]\n",
		     argv[0] );
      EXIT( LALSAMPLETESTC_EARG, argv[0], LALSAMPLETESTC_MSGEARG );
    }

  /* Compute ratio. */
  REAL8Divide( &stat, &ratio, atof( argv[1] ), atof( argv[2] ) );
  if ( stat.statusCode )
    EXIT( LALSAMPLETESTC_ESUB, argv[0], LALSAMPLETESTC_MSGESUB );

  /* Print result. */
  printf( "Ratio: %f / %f = %f\n", atof( argv[1] ), atof( argv[2] ),
	  ratio );
  EXIT( LALSAMPLETESTC_ENOM, argv[0], LALSAMPLETESTC_MSGENOM );
}
